==> owlapi-api-5.0.5-sources.jar: org/semanticweb/owlapi/model/OWLNaryPropertyAxiom.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.model;

import static org.semanticweb.owlapi.util.OWLAPIStreamUtils.asSet;

import java.util.Set;
import java.util.stream.Stream;

/**
 * @author Matthew Horridge, The University Of Manchester, Bio-Health
 *         Informatics Group
 * @since 2.0.0
 * @param
 *        <P>
 *        property expression
 */
public interface OWLNaryPropertyAxiom<P extends OWLPropertyExpression>
    extends OWLPropertyAxiom, OWLNaryAxiom<P>, HasOperands<P> {

    @Override
    default Stream<?> components() {
        return Stream.of(properties(), annotations());
    }

    @Override
    default Stream<?> componentsWithoutAnnotations() {
        return Stream.of(properties());
    }

    @Override
    default Stream<?> componentsAnnotationsFirst() {
        return Stream.of(annotations(), properties());
    }

    /**
     * @return all of the properties that appear in this axiom
     * @deprecated use the stream method
     */
    @Deprecated
    default Set<P> getProperties() {
        return asSet(properties());
    }

    /**
     * @return all of the properties that appear in this axiom
     */
    Stream<P> properties();

    @Override
    default Stream<P> operands() {
        return properties();
    }

    /**
     * @param property
     *        the property to skip
     * @return the set of properties minus property
     */
    Set<P> getPropertiesMinus(P property);
}

==> owlapi-api-5.1.11-sources.jar: org/semanticweb/owlapi/model/OWLNaryPropertyAxiom.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.model;

import static org.semanticweb.owlapi.util.OWLAPIStreamUtils.asSet;

import java.util.Set;
import java.util.stream.Stream;

/**
 * @param <P> property expression
 * @author Matthew Horridge, The University Of Manchester, Bio-Health Informatics Group
 * @since 2.0.0
 */
public interface OWLNaryPropertyAxiom<P extends OWLPropertyExpression>
    extends OWLPropertyAxiom, OWLNaryAxiom<P>, HasOperands<P> {

    @Override
    default Stream<?> components() {
        return Stream.of(getOperandsAsList(), annotationsAsList());
    }

    @Override
    default int initHashCode() {
        int hash = hashIndex();
        hash = OWLObject.hashIteration(hash, getOperandsAsList().hashCode());
        return OWLObject.hashIteration(hash, annotationsAsList().hashCode());
    }

    @Override
    default Stream<?> componentsWithoutAnnotations() {
        return Stream.of(getOperandsAsList());
    }

    @Override
    default Stream<?> componentsAnnotationsFirst() {
        return Stream.of(annotationsAsList(), getOperandsAsList());
    }

    /**
     * @return all of the properties that appear in this axiom
     * @deprecated use the stream method
     */
    @Deprecated
    default Set<P> getProperties() {
        return asSet(properties());
    }

    /**
     * @return all of the properties that appear in this axiom
     */
    Stream<P> properties();

    @Override
    default Stream<P> operands() {
        return properties();
    }

    /**
     * @param property the property to skip
     * @return the set of properties minus property
     */
    Set<P> getPropertiesMinus(P property);
}
